@@ -1,6 +1,6 @@
 __author__ = "filesystem"
 __copyright__ = "Copyright 2022-present CantCode"
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 import logging
 from typing import NamedTuple
@@ -10,7 +10,7 @@ try:
 except ImportError:
     from typing_extensions import Literal
 
-from .main import Money
+from .main import filelibrary
 
 class VersionInfo(NamedTuple):
     """
